@@ -5,7 +5,6 @@ from typing import Dict, Generic, Hashable, List, TypeVar
 from di.exceptions import DuplicateScopeError, UnknownScopeError
 from di.types.scopes import Scope
 
-T = TypeVar("T")
 KT = TypeVar("KT", bound=Hashable)
 VT = TypeVar("VT")
 
@@ -26,10 +25,10 @@ class ScopeMap(Generic[KT, VT]):
     ChainMap also doesn't allow you to set values anywhere but the left mapping, and we need to set values in arbitrary mappings.
     """
 
-    __slots__ = ("mappings",)
+    mappings: Dict[Scope, Dict[KT, VT]]
 
     def __init__(self) -> None:
-        self.mappings: Dict[Scope, Dict[KT, VT]] = {}
+        self.mappings = {}
 
     def get(self, key: KT) -> VT:
         for mapping in self.mappings.values():
@@ -68,7 +67,7 @@ class ScopeMap(Generic[KT, VT]):
         self.mappings.pop(scope)
 
     def copy(self) -> ScopeMap[KT, VT]:
-        new = ScopeMap[KT, VT]()
+        new = type(self)()
         new.mappings = self.mappings.copy()
         return new
 
